@@ -6,19 +6,27 @@ use strict;
 
 use Carp;
 use vars (qw($VERSION @ISA @EXPORT @EXPORT_OK $ntest $TestLevel), #public-ish
-	  qw($TESTOUT $ONFAIL %todo %history $planned @FAILDETAIL)#private-ish
+          qw($TESTOUT $ONFAIL %todo %history $planned @FAILDETAIL)#private-ish
          );
 
-$VERSION = '1.17';
+# In case a test is run in a persistent environment.
+sub _reset_globals {
+    %todo       = ();
+    %history    = ();
+    @FAILDETAIL = ();
+    $ntest      = 1;
+    $TestLevel  = 0;		# how many extra stack frames to skip
+    $planned    = 0;
+}
+
+$VERSION = '1.19';
 require Exporter;
 @ISA=('Exporter');
 
 @EXPORT    = qw(&plan &ok &skip);
 @EXPORT_OK = qw($ntest $TESTOUT);
 
-$TestLevel = 0;		# how many extra stack frames to skip
 $|=1;
-$ntest=1;
 $TESTOUT = *STDOUT{IO};
 
 # Use of this variable is strongly discouraged.  It is set mainly to
@@ -64,6 +72,9 @@ Test - provides a simple framework for writing test scripts
 
 =head1 DESCRIPTION
 
+B<STOP!> If you are writing a new test, we I<highly suggest> you use
+the new Test::Simple and Test::More modules instead.
+
 L<Test::Harness|Test::Harness> expects to see particular output when it
 executes tests.  This module aims to make writing proper test scripts just
 a little bit easier (and less error prone :-).
@@ -109,6 +120,8 @@ sub plan {
     local($\, $,);   # guard against -l and other things that screw with
                      # print
 
+    _reset_globals();
+
     my $max=0;
     for (my $x=0; $x < @_; $x+=2) {
 	my ($k,$v) = @_[$x,$x+1];
@@ -319,11 +332,12 @@ sub skip ($;$$$) {
         return 1;
     } else {
         # backwards compatiblity (I think).  skip() used to be
-        # called like ok() and was expected to fail, which is weird.
-        warn <<WARN if $^W;
-This looks like a skip() using the very old interface.  Please upgrade to
-the documented interface as this has been deprecated.
-WARN
+        # called like ok(), which is weird.  I haven't decided what to do with
+        # this yet.
+#        warn <<WARN if $^W;
+#This looks like a skip() using the very old interface.  Please upgrade to
+#the documented interface as this has been deprecated.
+#WARN
 
 	local($TestLevel) = $TestLevel+1;  #ignore this stack frame
         return &ok(@_);
@@ -435,6 +449,8 @@ L<Test::Simple>, L<Test::More>, L<Test::Harness>, L<Devel::Cover>
 
 L<Test::Unit> is an interesting alternative testing library.
 
+L<Pod::Tests> and L<SelfTest> let you embed tests in code.
+
 
 =head1 AUTHOR
 
@@ -445,7 +461,6 @@ Current maintainer, Michael G Schwern <schwern@pobox.com>
 
 This package is free software and is provided "as is" without express
 or implied warranty.  It may be used, redistributed and/or modified
-under the terms of the Perl Artistic License (see
-http://www.perl.com/perl/misc/Artistic.html)
+under the same terms as Perl itself.
 
 =cut
